@@ -150,11 +150,15 @@ around run => sub ( $orig, $self, $req ) {
                 namespace  => $self,
                 class_name => $extjs_class_name,
                 extend     => $extend,
-                cb         => sub ( $ext, $cfg ) {
+                cb         => sub ( $ext, $cfg, %args ) {
                     $ext->{cfg} = $cfg;
 
+                    my $headers = [ 'Content-Type' => 'application/javascript' ];
+
+                    push $headers->@*, $args{headers}->@*, if $args{headers};
+
                     # generate class
-                    $req->( 200, [ 'Content-Type' => 'application/javascript' ], $ext->to_js )->finish;
+                    $req->( 200, $headers, $ext->to_js )->finish;
 
                     return;
                 },
